window.Gleam.initSearch([{"doc":"glen","title":"glen","content":"# glen\n\n&lt;img src=&quot;https://raw.githubusercontent.com/MystPi/glen/main/assets/glen.png&quot; width=&quot;150&quot; align=&quot;right&quot; /&gt;\n\n[![Package Version](https://img.shields.io/hexpm/v/glen)](https://hex.pm/packages/glen)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glen/)\n\n🏕️ A peaceful web framework for Gleam that targets JS.\n\n✨ Features:\n\n- Request &amp; response helpers\n- Helpful middleware\n- File streaming\n- Bring-your-own server _(optional)_\n- Easily deploy on serverless platforms such as [Deno Deploy](https://deno.com/deploy)\n\n...and other nice-to-haves!\n\n## Installation\n\nInstall all requirements:\n\n```sh\ngleam add glen gleam_http gleam_javascript\n```\n\nOr just Glen:\n\n```sh\ngleam add glen\n```\n\n## Usage\n\n```gleam\nimport gleam/javascript/promise.{type Promise}\nimport glen\nimport glen/status\n\npub fn main() {\n  glen.serve(handle_req, 8000)\n}\n\nfn handle_req(req: glen.Request) -&gt; Promise(glen.Response) {\n  &quot;&lt;h1&gt;Welcome to my webpage!&lt;/h1&gt;\n  &lt;p&gt;Make yourself at home 😄&lt;/p&gt;&quot;\n  |&gt; glen.html(status.ok)\n  |&gt; promise.resolve\n}\n```\n\nGlen is heavily based off of [Wisp](https://github.com/gleam-wisp/wisp), and many of Wisp&#39;s [examples](https://github.com/gleam-wisp/wisp/tree/main/examples) can easily be ported to Glen. Glen also has an example application of its own in [./test](https://github.com/MystPi/glen/tree/main/test).\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glen&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the example application\n```\n","url":"index.html"},{"doc":"glen/status","title":"StatusType","content":"pub type StatusType {\n  Informational\n  Successful\n  Redirection\n  ClientError\n  ServerError\n}\n HTTP status codes are divided into 5 main groups:\n - Informational responses (100 – 199)\n - Successful responses (200 – 299)\n - Redirection messages (300 – 399)\n - Client error responses (400 – 499)\n - Server error responses (500 – 599)\nInformational\n\n\nSuccessful\n\n\nRedirection\n\n\nClientError\n\n\nServerError\n\n\nSynonyms:\nglen/status.StatusType\nglen/status StatusType","url":"glen/status.html#StatusType"},{"doc":"glen/status","title":"accepted","content":"pub const accepted: Int = 202\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/202)\nSynonyms:\nglen/status.accepted\nglen/status accepted","url":"glen/status.html#accepted"},{"doc":"glen/status","title":"already_reported","content":"pub const already_reported: Int = 208\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/208)\nSynonyms:\nglen/status.already_reported\nglen/status already_reported","url":"glen/status.html#already_reported"},{"doc":"glen/status","title":"bad_gateway","content":"pub const bad_gateway: Int = 502\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/502)\nSynonyms:\nglen/status.bad_gateway\nglen/status bad_gateway","url":"glen/status.html#bad_gateway"},{"doc":"glen/status","title":"bad_request","content":"pub const bad_request: Int = 400\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/400)\nSynonyms:\nglen/status.bad_request\nglen/status bad_request","url":"glen/status.html#bad_request"},{"doc":"glen/status","title":"client_closed_request","content":"pub const client_closed_request: Int = 499\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/499)\nSynonyms:\nglen/status.client_closed_request\nglen/status client_closed_request","url":"glen/status.html#client_closed_request"},{"doc":"glen/status","title":"conflict","content":"pub const conflict: Int = 409\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/409)\nSynonyms:\nglen/status.conflict\nglen/status conflict","url":"glen/status.html#conflict"},{"doc":"glen/status","title":"connection_closed_without_response","content":"pub const connection_closed_without_response: Int = 444\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/444)\nSynonyms:\nglen/status.connection_closed_without_response\nglen/status connection_closed_without_response","url":"glen/status.html#connection_closed_without_response"},{"doc":"glen/status","title":"continue","content":"pub const continue: Int = 100\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/100)\nSynonyms:\nglen/status.continue\nglen/status continue","url":"glen/status.html#continue"},{"doc":"glen/status","title":"created","content":"pub const created: Int = 201\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/201)\nSynonyms:\nglen/status.created\nglen/status created","url":"glen/status.html#created"},{"doc":"glen/status","title":"early_hints","content":"pub const early_hints: Int = 103\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/103)\nSynonyms:\nglen/status.early_hints\nglen/status early_hints","url":"glen/status.html#early_hints"},{"doc":"glen/status","title":"expectation_failed","content":"pub const expectation_failed: Int = 417\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/417)\nSynonyms:\nglen/status.expectation_failed\nglen/status expectation_failed","url":"glen/status.html#expectation_failed"},{"doc":"glen/status","title":"failed_dependency","content":"pub const failed_dependency: Int = 424\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/424)\nSynonyms:\nglen/status.failed_dependency\nglen/status failed_dependency","url":"glen/status.html#failed_dependency"},{"doc":"glen/status","title":"forbidden","content":"pub const forbidden: Int = 403\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/403)\nSynonyms:\nglen/status.forbidden\nglen/status forbidden","url":"glen/status.html#forbidden"},{"doc":"glen/status","title":"found","content":"pub const found: Int = 302\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/302)\nSynonyms:\nglen/status.found\nglen/status found","url":"glen/status.html#found"},{"doc":"glen/status","title":"gateway_timeout","content":"pub const gateway_timeout: Int = 504\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/504)\nSynonyms:\nglen/status.gateway_timeout\nglen/status gateway_timeout","url":"glen/status.html#gateway_timeout"},{"doc":"glen/status","title":"gone","content":"pub const gone: Int = 410\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/410)\nSynonyms:\nglen/status.gone\nglen/status gone","url":"glen/status.html#gone"},{"doc":"glen/status","title":"http_version_not_supported","content":"pub const http_version_not_supported: Int = 505\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/505)\nSynonyms:\nglen/status.http_version_not_supported\nglen/status http_version_not_supported","url":"glen/status.html#http_version_not_supported"},{"doc":"glen/status","title":"im_a_teapot","content":"pub const im_a_teapot: Int = 418\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/418)\nSynonyms:\nglen/status.im_a_teapot\nglen/status im_a_teapot","url":"glen/status.html#im_a_teapot"},{"doc":"glen/status","title":"im_used","content":"pub const im_used: Int = 226\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/226)\nSynonyms:\nglen/status.im_used\nglen/status im_used","url":"glen/status.html#im_used"},{"doc":"glen/status","title":"insufficient_storage","content":"pub const insufficient_storage: Int = 507\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/507)\nSynonyms:\nglen/status.insufficient_storage\nglen/status insufficient_storage","url":"glen/status.html#insufficient_storage"},{"doc":"glen/status","title":"internal_server_error","content":"pub const internal_server_error: Int = 500\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/500)\nSynonyms:\nglen/status.internal_server_error\nglen/status internal_server_error","url":"glen/status.html#internal_server_error"},{"doc":"glen/status","title":"length_required","content":"pub const length_required: Int = 411\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/411)\nSynonyms:\nglen/status.length_required\nglen/status length_required","url":"glen/status.html#length_required"},{"doc":"glen/status","title":"locked","content":"pub const locked: Int = 423\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/423)\nSynonyms:\nglen/status.locked\nglen/status locked","url":"glen/status.html#locked"},{"doc":"glen/status","title":"loop_detected","content":"pub const loop_detected: Int = 508\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/508)\nSynonyms:\nglen/status.loop_detected\nglen/status loop_detected","url":"glen/status.html#loop_detected"},{"doc":"glen/status","title":"method_not_allowed","content":"pub const method_not_allowed: Int = 405\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/405)\nSynonyms:\nglen/status.method_not_allowed\nglen/status method_not_allowed","url":"glen/status.html#method_not_allowed"},{"doc":"glen/status","title":"misdirected_request","content":"pub const misdirected_request: Int = 421\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/421)\nSynonyms:\nglen/status.misdirected_request\nglen/status misdirected_request","url":"glen/status.html#misdirected_request"},{"doc":"glen/status","title":"moved_permanently","content":"pub const moved_permanently: Int = 301\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/301)\nSynonyms:\nglen/status.moved_permanently\nglen/status moved_permanently","url":"glen/status.html#moved_permanently"},{"doc":"glen/status","title":"multi_status","content":"pub const multi_status: Int = 207\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/207)\nSynonyms:\nglen/status.multi_status\nglen/status multi_status","url":"glen/status.html#multi_status"},{"doc":"glen/status","title":"multiple_choices","content":"pub const multiple_choices: Int = 300\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/300)\nSynonyms:\nglen/status.multiple_choices\nglen/status multiple_choices","url":"glen/status.html#multiple_choices"},{"doc":"glen/status","title":"network_authentication_required","content":"pub const network_authentication_required: Int = 511\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/511)\nSynonyms:\nglen/status.network_authentication_required\nglen/status network_authentication_required","url":"glen/status.html#network_authentication_required"},{"doc":"glen/status","title":"network_connect_timeout_error","content":"pub const network_connect_timeout_error: Int = 599\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/599)\nSynonyms:\nglen/status.network_connect_timeout_error\nglen/status network_connect_timeout_error","url":"glen/status.html#network_connect_timeout_error"},{"doc":"glen/status","title":"no_content","content":"pub const no_content: Int = 204\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/204)\nSynonyms:\nglen/status.no_content\nglen/status no_content","url":"glen/status.html#no_content"},{"doc":"glen/status","title":"non_authoritative_information","content":"pub const non_authoritative_information: Int = 203\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/203)\nSynonyms:\nglen/status.non_authoritative_information\nglen/status non_authoritative_information","url":"glen/status.html#non_authoritative_information"},{"doc":"glen/status","title":"not_acceptable","content":"pub const not_acceptable: Int = 406\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/406)\nSynonyms:\nglen/status.not_acceptable\nglen/status not_acceptable","url":"glen/status.html#not_acceptable"},{"doc":"glen/status","title":"not_extended","content":"pub const not_extended: Int = 510\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/510)\nSynonyms:\nglen/status.not_extended\nglen/status not_extended","url":"glen/status.html#not_extended"},{"doc":"glen/status","title":"not_found","content":"pub const not_found: Int = 404\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/404)\nSynonyms:\nglen/status.not_found\nglen/status not_found","url":"glen/status.html#not_found"},{"doc":"glen/status","title":"not_implemented","content":"pub const not_implemented: Int = 501\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/501)\nSynonyms:\nglen/status.not_implemented\nglen/status not_implemented","url":"glen/status.html#not_implemented"},{"doc":"glen/status","title":"not_modified","content":"pub const not_modified: Int = 304\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/304)\nSynonyms:\nglen/status.not_modified\nglen/status not_modified","url":"glen/status.html#not_modified"},{"doc":"glen/status","title":"ok","content":"pub const ok: Int = 200\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/200)\nSynonyms:\nglen/status.ok\nglen/status ok","url":"glen/status.html#ok"},{"doc":"glen/status","title":"partial_content","content":"pub const partial_content: Int = 206\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/206)\nSynonyms:\nglen/status.partial_content\nglen/status partial_content","url":"glen/status.html#partial_content"},{"doc":"glen/status","title":"payload_too_large","content":"pub const payload_too_large: Int = 413\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/413)\nSynonyms:\nglen/status.payload_too_large\nglen/status payload_too_large","url":"glen/status.html#payload_too_large"},{"doc":"glen/status","title":"payment_required","content":"pub const payment_required: Int = 402\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/402)\nSynonyms:\nglen/status.payment_required\nglen/status payment_required","url":"glen/status.html#payment_required"},{"doc":"glen/status","title":"permanent_redirect","content":"pub const permanent_redirect: Int = 308\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/308)\nSynonyms:\nglen/status.permanent_redirect\nglen/status permanent_redirect","url":"glen/status.html#permanent_redirect"},{"doc":"glen/status","title":"precondition_failed","content":"pub const precondition_failed: Int = 412\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/412)\nSynonyms:\nglen/status.precondition_failed\nglen/status precondition_failed","url":"glen/status.html#precondition_failed"},{"doc":"glen/status","title":"precondition_required","content":"pub const precondition_required: Int = 428\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/428)\nSynonyms:\nglen/status.precondition_required\nglen/status precondition_required","url":"glen/status.html#precondition_required"},{"doc":"glen/status","title":"processing","content":"pub const processing: Int = 102\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/102)\nSynonyms:\nglen/status.processing\nglen/status processing","url":"glen/status.html#processing"},{"doc":"glen/status","title":"proxy_authentication_required","content":"pub const proxy_authentication_required: Int = 407\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/407)\nSynonyms:\nglen/status.proxy_authentication_required\nglen/status proxy_authentication_required","url":"glen/status.html#proxy_authentication_required"},{"doc":"glen/status","title":"request_header_fields_too_large","content":"pub const request_header_fields_too_large: Int = 431\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/431)\nSynonyms:\nglen/status.request_header_fields_too_large\nglen/status request_header_fields_too_large","url":"glen/status.html#request_header_fields_too_large"},{"doc":"glen/status","title":"request_timeout","content":"pub const request_timeout: Int = 408\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/408)\nSynonyms:\nglen/status.request_timeout\nglen/status request_timeout","url":"glen/status.html#request_timeout"},{"doc":"glen/status","title":"request_uri_too_long","content":"pub const request_uri_too_long: Int = 414\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/414)\nSynonyms:\nglen/status.request_uri_too_long\nglen/status request_uri_too_long","url":"glen/status.html#request_uri_too_long"},{"doc":"glen/status","title":"requested_range_not_satisfiable","content":"pub const requested_range_not_satisfiable: Int = 416\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/416)\nSynonyms:\nglen/status.requested_range_not_satisfiable\nglen/status requested_range_not_satisfiable","url":"glen/status.html#requested_range_not_satisfiable"},{"doc":"glen/status","title":"reset_content","content":"pub const reset_content: Int = 205\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/205)\nSynonyms:\nglen/status.reset_content\nglen/status reset_content","url":"glen/status.html#reset_content"},{"doc":"glen/status","title":"see_other","content":"pub const see_other: Int = 303\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/303)\nSynonyms:\nglen/status.see_other\nglen/status see_other","url":"glen/status.html#see_other"},{"doc":"glen/status","title":"service_unavailable","content":"pub const service_unavailable: Int = 503\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/503)\nSynonyms:\nglen/status.service_unavailable\nglen/status service_unavailable","url":"glen/status.html#service_unavailable"},{"doc":"glen/status","title":"switching_protocols","content":"pub const switching_protocols: Int = 101\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/101)\nSynonyms:\nglen/status.switching_protocols\nglen/status switching_protocols","url":"glen/status.html#switching_protocols"},{"doc":"glen/status","title":"temporary_redirect","content":"pub const temporary_redirect: Int = 307\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/307)\nSynonyms:\nglen/status.temporary_redirect\nglen/status temporary_redirect","url":"glen/status.html#temporary_redirect"},{"doc":"glen/status","title":"too_many_requests","content":"pub const too_many_requests: Int = 429\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/429)\nSynonyms:\nglen/status.too_many_requests\nglen/status too_many_requests","url":"glen/status.html#too_many_requests"},{"doc":"glen/status","title":"unauthorized","content":"pub const unauthorized: Int = 401\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/401)\nSynonyms:\nglen/status.unauthorized\nglen/status unauthorized","url":"glen/status.html#unauthorized"},{"doc":"glen/status","title":"unavailable_for_legal_reasons","content":"pub const unavailable_for_legal_reasons: Int = 451\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/451)\nSynonyms:\nglen/status.unavailable_for_legal_reasons\nglen/status unavailable_for_legal_reasons","url":"glen/status.html#unavailable_for_legal_reasons"},{"doc":"glen/status","title":"unprocessable_entity","content":"pub const unprocessable_entity: Int = 422\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/422)\nSynonyms:\nglen/status.unprocessable_entity\nglen/status unprocessable_entity","url":"glen/status.html#unprocessable_entity"},{"doc":"glen/status","title":"unsupported_media_type","content":"pub const unsupported_media_type: Int = 415\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/415)\nSynonyms:\nglen/status.unsupported_media_type\nglen/status unsupported_media_type","url":"glen/status.html#unsupported_media_type"},{"doc":"glen/status","title":"upgrade_required","content":"pub const upgrade_required: Int = 426\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/426)\nSynonyms:\nglen/status.upgrade_required\nglen/status upgrade_required","url":"glen/status.html#upgrade_required"},{"doc":"glen/status","title":"use_proxy","content":"pub const use_proxy: Int = 305\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/305)\nSynonyms:\nglen/status.use_proxy\nglen/status use_proxy","url":"glen/status.html#use_proxy"},{"doc":"glen/status","title":"variant_also_negotiates","content":"pub const variant_also_negotiates: Int = 506\n [Documentation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/506)\nSynonyms:\nglen/status.variant_also_negotiates\nglen/status variant_also_negotiates","url":"glen/status.html#variant_also_negotiates"},{"doc":"glen/status","title":"classify","content":"pub fn classify(status: Int) -&gt; StatusType\n Classify a status code into a [`StatusType`](#StatusType).\nSynonyms:\nglen/status.classify\nglen/status classify","url":"glen/status.html#classify"},{"doc":"glen/status","title":"glen/status","content":" This module provides an easy way to reference\n [HTTP status codes](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status)\n and some extra utilities for working with them.\n\n ```\n status.not_found\n |&gt; status.classify\n // -&gt; ClientError\n ```","url":"glen/status.html"},{"doc":"glen","title":"Handler","content":"pub type Handler =\n  fn(Request) -&gt; Promise(Response)\n A request handler.\n\n # Examples\n\n \n fn my_serve(handler: glen.Handler, port: Int) -&gt; Nil {\n   io.println(&quot;Starting server...&quot;)\n   glen.serve(handler, port)\n }\n \n\nSynonyms:\nglen.Handler\nglen Handler","url":"glen.html#Handler"},{"doc":"glen","title":"JsHandler","content":"pub type JsHandler =\n  fn(JsRequest) -&gt; Promise(JsResponse)\n A JavaScript request handler.\n\nSynonyms:\nglen.JsHandler\nglen JsHandler","url":"glen.html#JsHandler"},{"doc":"glen","title":"Request","content":"pub type Request =\n  HttpRequest(RequestBody)\n An incoming request.\n\nSynonyms:\nglen.Request\nglen Request","url":"glen.html#Request"},{"doc":"glen","title":"RequestBody","content":"pub type RequestBody =\n  conversation.RequestBody\n An incoming request&#39;s body.\n\nSynonyms:\nglen.RequestBody\nglen RequestBody","url":"glen.html#RequestBody"},{"doc":"glen","title":"Response","content":"pub type Response =\n  HttpResponse(ResponseBody)\n An outgoing response.\n\nSynonyms:\nglen.Response\nglen Response","url":"glen.html#Response"},{"doc":"glen","title":"ResponseBody","content":"pub type ResponseBody {\n  Text(String)\n  File(path: String)\n  Bits(BitArray)\n  Empty\n}\n An outgoing response&#39;s body.\nText(String)\n A text body.\n\nFile(path: String)\n A file body. The file will be streamed and not read into memory, so it is\n okay to send files of any size. If the file cannot be accessed, an empty\n response with a 500 status code (internal server error) will be returned.\n\nBits(BitArray)\n A `BitArray` body.\n\nEmpty\n An empty body, equivalent to `Bits(&lt;&lt;&gt;&gt;)`.\n\nSynonyms:\nglen.ResponseBody\nglen ResponseBody","url":"glen.html#ResponseBody"},{"doc":"glen","title":"path_segments","content":"pub const path_segments: fn(Request(RequestBody)) -&gt; List(String) = request.path_segments\n Return the non-empty segments of a request path.\n\n &gt; ℹ️ This function is re-exported from `gleam_http`.\n\n # Examples\n\n \n case glen.path_segments(req) {\n   [] -&gt; index_page()\n   [&quot;about&quot;] -&gt; about_page()\n   [&quot;greet&quot;, name] -&gt; greet_page(name)\n   _ -&gt; not_found_page()\n }\n \nSynonyms:\nglen.path_segments\nglen path_segments","url":"glen.html#path_segments"},{"doc":"glen","title":"set_body","content":"pub const set_body: fn(Response(ResponseBody), ResponseBody) -&gt;\n  Response(ResponseBody) = response.set_body\n Set the body of a response.\n\n &gt; ℹ️ This function is re-exported from `gleam_http`.\nSynonyms:\nglen.set_body\nglen set_body","url":"glen.html#set_body"},{"doc":"glen","title":"set_header","content":"pub const set_header: fn(Response(ResponseBody), String, String) -&gt;\n  Response(ResponseBody) = response.set_header\n Set the header with the given value under the given header key.\n\n If the response already has that key, it is replaced.\n\n &gt; ℹ️ This function is re-exported from `gleam_http`.\nSynonyms:\nglen.set_header\nglen set_header","url":"glen.html#set_header"},{"doc":"glen","title":"bit_array_body","content":"pub fn bit_array_body(\n  res: Response(ResponseBody),\n  bits: BitArray,\n) -&gt; Response(ResponseBody)\n Set the body of a response to a `BitArray`.\nSynonyms:\nglen.bit_array_body\nglen bit_array_body","url":"glen.html#bit_array_body"},{"doc":"glen","title":"custom_serve","content":"pub fn custom_serve(\n  handler: fn(Request(RequestBody)) -&gt;\n    Promise(Response(ResponseBody)),\n  server: fn(fn(JsRequest) -&gt; Promise(JsResponse), Int) -&gt; Nil,\n  port: Int,\n) -&gt; Nil\n Start a server using a custom JavaScript server.\n\n &gt; ℹ️ The [`serve`](#serve) function is recommended when using the `deno` runtime.\n\n &gt; ℹ️ For lower-level customizability and API freedom, consider using the\n [`js_to_glen_request`](#js_to_glen_request) and\n [`glen_to_js_response`](#glen_to_js_response) functions.\n\n # Examples\n\n \n @external(javascript, &quot;./serve.mjs&quot;, &quot;serve&quot;)\n fn my_serve(handler: glen.JsHandler) -&gt; Nil\n\n fn(_req) {\n   &quot;Hello, world!&quot;\n   |&gt; glen.text(status.ok)\n   |&gt; promise.resolve\n }\n |&gt; glen.custom_serve(my_serve, 8000)\n \nSynonyms:\nglen.custom_serve\nglen custom_serve","url":"glen.html#custom_serve"},{"doc":"glen","title":"escape_html","content":"pub fn escape_html(string: String) -&gt; String\n Escape a string so it can be included inside of HTML safely. You should run\n this function on all user input being included in HTML to prevent possible\n [XSS attacks](https://en.wikipedia.org/wiki/Cross-site_scripting).\nSynonyms:\nglen.escape_html\nglen escape_html","url":"glen.html#escape_html"},{"doc":"glen","title":"file","content":"pub fn file(path: String, status: Int) -&gt; Response(ResponseBody)\n Create a response with a file stream as the body. The `content-type` header\n will be automatically set based on the file&#39;s extension.\nSynonyms:\nglen.file\nglen file","url":"glen.html#file"},{"doc":"glen","title":"file_body","content":"pub fn file_body(\n  res: Response(ResponseBody),\n  path: String,\n) -&gt; Response(ResponseBody)\n Set the body of a response to a file stream. The `content-type` header\n will be automatically set based on the file&#39;s extension.\nSynonyms:\nglen.file_body\nglen file_body","url":"glen.html#file_body"},{"doc":"glen","title":"get_query","content":"pub fn get_query(\n  req: Request(RequestBody),\n) -&gt; List(#(String, String))\n Get the query parameters from a request. Parameters are not predictably\n ordered, so you should not pattern match on them. Instead, use the\n [`key_find`](https://hexdocs.pm/gleam_stdlib/gleam/list.html#key_find)\n function from `gleam/list` to access parameters.\nSynonyms:\nglen.get_query\nglen get_query","url":"glen.html#get_query"},{"doc":"glen","title":"glen_to_js_response","content":"pub fn glen_to_js_response(\n  res: Response(ResponseBody),\n) -&gt; JsResponse\n Translate a Glen response into a JavaScript response.\nSynonyms:\nglen.glen_to_js_response\nglen glen_to_js_response","url":"glen.html#glen_to_js_response"},{"doc":"glen","title":"html","content":"pub fn html(html: String, status: Int) -&gt; Response(ResponseBody)\n Create a response with an HTML body.\nSynonyms:\nglen.html\nglen html","url":"glen.html#html"},{"doc":"glen","title":"html_body","content":"pub fn html_body(\n  res: Response(ResponseBody),\n  html: String,\n) -&gt; Response(ResponseBody)\n Set the body of a response to HTML.\nSynonyms:\nglen.html_body\nglen html_body","url":"glen.html#html_body"},{"doc":"glen","title":"js_to_glen_request","content":"pub fn js_to_glen_request(req: JsRequest) -&gt; Request(RequestBody)\n Translate a JavaScript request into a Glen request.\nSynonyms:\nglen.js_to_glen_request\nglen js_to_glen_request","url":"glen.html#js_to_glen_request"},{"doc":"glen","title":"json","content":"pub fn json(json: String, status: Int) -&gt; Response(ResponseBody)\n Create a response with a JSON body.\nSynonyms:\nglen.json\nglen json","url":"glen.html#json"},{"doc":"glen","title":"json_body","content":"pub fn json_body(\n  res: Response(ResponseBody),\n  json: String,\n) -&gt; Response(ResponseBody)\n Set the body of a response to JSON.\nSynonyms:\nglen.json_body\nglen json_body","url":"glen.html#json_body"},{"doc":"glen","title":"log","content":"pub fn log(\n  req: Request(RequestBody),\n  next: fn() -&gt; Promise(Response(ResponseBody)),\n) -&gt; Promise(Response(ResponseBody))\n Middleware function for logging requests and responses.\n\n # Examples\n\n \n fn handle_req(req) {\n   use &lt;- glen.log(req)\n   // ...requests and responses are now logged...\n }\n \nSynonyms:\nglen.log\nglen log","url":"glen.html#log"},{"doc":"glen","title":"method_not_allowed","content":"pub fn method_not_allowed(\n  allowed: List(Method),\n) -&gt; Response(ResponseBody)\n Create a response with a status of 405 (method not allowed). The `allowed`\n header will be set to the given allowed methods.\nSynonyms:\nglen.method_not_allowed\nglen method_not_allowed","url":"glen.html#method_not_allowed"},{"doc":"glen","title":"read_body_bits","content":"pub fn read_body_bits(\n  req: Request(RequestBody),\n) -&gt; Promise(Result(BitArray, ReadError))\n Read a request body as a `BitArray`.\nSynonyms:\nglen.read_body_bits\nglen read_body_bits","url":"glen.html#read_body_bits"},{"doc":"glen","title":"read_form_body","content":"pub fn read_form_body(\n  req: Request(RequestBody),\n) -&gt; Promise(Result(FormData, ReadError))\n Read a request body as [`FormData`](https://hexdocs.pm/conversation/conversation.html#FormData).\nSynonyms:\nglen.read_form_body\nglen read_form_body","url":"glen.html#read_form_body"},{"doc":"glen","title":"read_json_body","content":"pub fn read_json_body(\n  req: Request(RequestBody),\n) -&gt; Promise(Result(Dynamic, ReadError))\n Read a request body as JSON.\nSynonyms:\nglen.read_json_body\nglen read_json_body","url":"glen.html#read_json_body"},{"doc":"glen","title":"read_text_body","content":"pub fn read_text_body(\n  req: Request(RequestBody),\n) -&gt; Promise(Result(String, ReadError))\n Read a request body as text.\nSynonyms:\nglen.read_text_body\nglen read_text_body","url":"glen.html#read_text_body"},{"doc":"glen","title":"redirect","content":"pub fn redirect(\n  url: String,\n  status: Int,\n) -&gt; Response(ResponseBody)\n Redirect the client to a URL with the given status. The status should be\n in the 3xx range (such as `303: See Other` or `307: Temporary Redirect`).\nSynonyms:\nglen.redirect\nglen redirect","url":"glen.html#redirect"},{"doc":"glen","title":"require_bit_array_body","content":"pub fn require_bit_array_body(\n  req: Request(RequestBody),\n  next: fn(BitArray) -&gt; Promise(Response(ResponseBody)),\n) -&gt; Promise(Response(ResponseBody))\n Middleware function that reads a request body as a `BitArray`.\n\n # Examples\n\n \n fn handle_req(req) {\n   use bits &lt;- glen.require_bit_array_body(req)\n\n   &quot;Look at all the bits! &quot; &lt;&gt; string.inspect(bits)\n   |&gt; glen.html(status.ok)\n   |&gt; promise.resolve\n }\n \nSynonyms:\nglen.require_bit_array_body\nglen require_bit_array_body","url":"glen.html#require_bit_array_body"},{"doc":"glen","title":"require_content_type","content":"pub fn require_content_type(\n  req: Request(RequestBody),\n  required: String,\n  next: fn() -&gt; Promise(Response(ResponseBody)),\n) -&gt; Promise(Response(ResponseBody))\n Middleware function for requiring the request to have a `content-type` header\n with a specific content type. Returns the same as\n [`unsupported_media_type`](#unsupported_media_type) if the header is missing\n or does not meet the requirement.\n\n # Examples\n\n \n fn handle_req(req) {\n   use &lt;- glen.require_content_type(req, &quot;text/html&quot;)\n   // ...the request&#39;s content-type must be text/html...\n }\n \nSynonyms:\nglen.require_content_type\nglen require_content_type","url":"glen.html#require_content_type"},{"doc":"glen","title":"require_form","content":"pub fn require_form(\n  req: Request(RequestBody),\n  next: fn(FormData) -&gt; Promise(Response(ResponseBody)),\n) -&gt; Promise(Response(ResponseBody))\n Middleware for requiring the request body to be a form with a `content-type`\n of either `application/x-www-form-urlencoded` or `multipart/form-data`.\n\n Formdata values are sorted alphabetically so they can be pattern matched on.\n\n # Examples\n\n \n fn handle_req(req) {\n   use formdata &lt;- glen.require_form(req)\n\n   case formdata.values {\n     [#(&quot;name&quot;, name)] -&gt; greet(name)\n     _ -&gt; glen.response(status.bad_request)\n   }\n   |&gt; promise.resolve\n }\n \nSynonyms:\nglen.require_form\nglen require_form","url":"glen.html#require_form"},{"doc":"glen","title":"require_json","content":"pub fn require_json(\n  req: Request(RequestBody),\n  next: fn(Dynamic) -&gt; Promise(Response(ResponseBody)),\n) -&gt; Promise(Response(ResponseBody))\n Middleware function for requiring the request body to be JSON with a\n `content-type` of `application/json`.\n\n # Examples\n\n \n fn handle_req(req) {\n   use json &lt;- glen.require_json(req)\n\n   case my_decoder(json) {\n     Ok(decoded) -&gt; decoded.foo |&gt; glen.text(status.ok)\n     Error(_) -&gt; glen.response(status.bad_request)\n   }\n   |&gt; promise.resolve\n }\n \nSynonyms:\nglen.require_json\nglen require_json","url":"glen.html#require_json"},{"doc":"glen","title":"require_method","content":"pub fn require_method(\n  req: Request(RequestBody),\n  method: Method,\n  next: fn() -&gt; Promise(Response(ResponseBody)),\n) -&gt; Promise(Response(ResponseBody))\n Middleware function for requiring the request to be of a certain HTTP method.\n Returns the same as [`method_not_allowed`](#method_not_allowed) if the method\n does not meet the requirement.\n\n # Examples\n\n \n fn handle_req(req) {\n   use &lt;- glen.require_method(req, http.Get)\n   // ...only GET requests are allowed...\n }\n \nSynonyms:\nglen.require_method\nglen require_method","url":"glen.html#require_method"},{"doc":"glen","title":"require_string_body","content":"pub fn require_string_body(\n  req: Request(RequestBody),\n  next: fn(String) -&gt; Promise(Response(ResponseBody)),\n) -&gt; Promise(Response(ResponseBody))\n Middleware function that reads a request body as a string.\n\n # Examples\n\n \n fn handle_req(req) {\n   use string_body &lt;- glen.require_string_body(req)\n\n   &quot;You gave me: &quot; &lt;&gt; glen.escape_html(string_body)\n   |&gt; glen.html(status.ok)\n   |&gt; promise.resolve\n }\n \nSynonyms:\nglen.require_string_body\nglen require_string_body","url":"glen.html#require_string_body"},{"doc":"glen","title":"rescue_crashes","content":"pub fn rescue_crashes(\n  handler: fn() -&gt; Promise(Response(ResponseBody)),\n) -&gt; Promise(Response(ResponseBody))\n Middleware function that rescues any crashes with an empty response and a\n status of 500 (internal server error).\n\n Gleam code should never crash under normal circumstances, but it&#39;s always good\n to be prepared.\n\n # Examples\n\n \n fn handle_req(req) {\n   use &lt;- glen.rescue_crashes\n   // ...crashes are now handled gracefully...\n }\n \nSynonyms:\nglen.rescue_crashes\nglen rescue_crashes","url":"glen.html#rescue_crashes"},{"doc":"glen","title":"response","content":"pub fn response(status: Int) -&gt; Response(ResponseBody)\n Create a response with the given status code and an empty body.\nSynonyms:\nglen.response\nglen response","url":"glen.html#response"},{"doc":"glen","title":"serve","content":"pub fn serve(\n  handler: fn(Request(RequestBody)) -&gt;\n    Promise(Response(ResponseBody)),\n  port: Int,\n) -&gt; Nil\n Start a server using `Deno.serve`.\n\n &gt; ℹ️ Only works when using the `deno` runtime. Try [`custom_serve`](#custom_serve)\n for other runtimes such as Node.js.\n\n # Examples\n\n \n fn(_req) {\n   &quot;Hello, world!&quot;\n   |&gt; glen.text(status.ok)\n   |&gt; promise.resolve\n }\n |&gt; glen.serve(8000)\n \nSynonyms:\nglen.serve\nglen serve","url":"glen.html#serve"},{"doc":"glen","title":"static","content":"pub fn static(\n  req: Request(RequestBody),\n  prefix: String,\n  directory: String,\n  next: fn() -&gt; Promise(Response(ResponseBody)),\n) -&gt; Promise(Response(ResponseBody))\n Middleware for serving up static files from a directory under a path prefix.\n\n # Examples\n\n \n fn handle_req(req) {\n   use &lt;- glen.static(req, &quot;static&quot;, &quot;./somedir/static&quot;)\n\n   &quot;&lt;img src=&#39;/static/image.png&#39;/&gt;&quot; |&gt; glen.html(status.ok) |&gt; promise.resolve\n }\n \nSynonyms:\nglen.static\nglen static","url":"glen.html#static"},{"doc":"glen","title":"text","content":"pub fn text(text: String, status: Int) -&gt; Response(ResponseBody)\n Create a response with a text body.\nSynonyms:\nglen.text\nglen text","url":"glen.html#text"},{"doc":"glen","title":"text_body","content":"pub fn text_body(\n  res: Response(ResponseBody),\n  text: String,\n) -&gt; Response(ResponseBody)\n Set the body of a response to text.\nSynonyms:\nglen.text_body\nglen text_body","url":"glen.html#text_body"},{"doc":"glen","title":"unsupported_media_type","content":"pub fn unsupported_media_type(\n  supported: List(String),\n) -&gt; Response(ResponseBody)\n Create a response with a status of 415 (unsupported media type). The `accept`\n header will be set to the given supported content types.\nSynonyms:\nglen.unsupported_media_type\nglen unsupported_media_type","url":"glen.html#unsupported_media_type"},{"doc":"glen","title":"glen","content":" 🏕️ A peaceful web framework that targets JS.\n\n Other packages you will need:\n - [`gleam_http`](https://hexdocs.pm/gleam_http/) — everything `Request` and\n `Response` related\n - [`gleam_javascript`](https://hexdocs.pm/gleam_javascript/) — provides tools\n for working with JavaScript promises.","url":"glen.html"}]);